--[[
	Receiver functions for handling data communications
]]

-- Processes receipt of data
-- Enter all storm data into records
function navcomp.com:DataReceived (sender, data)
	local receivedSystems = {}
	navcomp.data.isStormDataSaved = false
	local v, sysId
	if data.storms then
		for _,v in ipairs (data.storms) do
			if not string.find (navcomp.data.stormSectorStr, "|" .. v .. "|") then
				table.insert (navcomp.data.stormSectors, v)
				navcomp.data:AddToStormString (v)
				sysId = GetSystemID (v)
				receivedSystems [sysId] = "YES"
			end
		end
	end
	if data.hive then
		for _,v in ipairs (data.hive) do
			if not string.find (navcomp.data.botSectorStr, "|" .. v.."|") then
				table.insert (navcomp.data.botSectors, v)
				navcomp.data:AddToBotString (v)
				sysId = GetSystemID (v)
				receivedSystems [sysId] = "YES"
			end
		end
	end
	navcomp.data:SaveStormSectors ()
	
	-- Remove all new encounter systems from map cache
	for sysId, _ in pairs (receivedSystems) do
		navcomp.data.stressMaps [sysId] = nil
	end
	
	-- Inform user of list of received Systems
	navcomp:Print (string.format ("Received Encounter Data from %s", sender))
	if #data == 0 then
		navcomp:Print ("None")
	end
	for sysId, _ in pairs (receivedSystems) do
		navcomp:Print (SystemNames [sysId])
	end
end

-- Processes receipt of navpath
-- Save path sectors to storage
function navcomp.com:PathReceived (sender, data)
	local receivedRoutes = {}
	if #data > 0 then
		local route
		for _, route in ipairs (data) do
			navcomp.data:SavePathNote (navcomp.data:SetPathDefaults (route))
			receivedRoutes [route.name] = "YES"
		end
		navcomp.data:SavePathNotes ()
		
		-- Inform user of list of new routes received
		navcomp:Print (string.format ("Received Navroutes from %s", sender))
		for route, _ in pairs (receivedRoutes) do
			navcomp:Print (route)
		end
	end
end

function navcomp.com:AnchorsReceived (sender, data)
	-- for all sectors in received data, overwrite existing sector anchors
	local target, anchor, sysId, note, anchorStr, x, y, before, after
	if #data > 0 then
		navcomp:Print (string.format ("Received Anchors from %s", sender))
	end
	for _, target in ipairs (data) do
		-- Save the received anchor data
		navcomp.data.anchors [target.sectorId] = target.anchors
		
		-- Rewrite the sector note for the given sector
		sysId = GetSystemID (target.sectorId)
		note = SystemNotes [sysId][target.sectorId]
		local i1, i2 = string.find (note, "#anchors%s*%([%*?%a%-?%d%d?%s*,?]+%):")
		before = string.sub (note, 1, i1-1)
		after = string.sub (note, i2+1)
		
		--Build anchor string
		anchorStr = "#anchors ("
		for _, anchor in ipairs (target.anchors) do
			sysId, y, x = SplitSectorID (anchor.s)
			if anchor.override then
				anchorStr = anchorStr .. "*"
			end
			anchorStr = anchorStr .. navcomp.data.columnNumbers [y] .. tostring (x)
			anchorStr = anchorStr .. ", "
		end
		anchorStr = string.sub (anchorStr, 1, anchorStr:len ()-2)
		anchorStr = anchorStr .. "):"
		
		-- Rebuild sector note
		note = before .. anchorStr .. after
		SystemNotes [sysId][target.sectorId] = note
		
		-- Inform user of new anchor received
		navcomp:Print (LocationStr (target.sectorId))
		
		-- Resync data
		navcomp:SyncSectorNotes ()
		purchaseprint ("Synchronization Complete")
	end
end